/// <reference types="node" />
/// <reference types="aws-sdk" />
declare module 'cdk-web/cli' {
  export = PseudoCli;
  /**
   * @typedef {Object} CloudFormationTemplate
   * @description JSON representation of a CloudFormation stack
   */
  /**
   * @typedef {Object} DeployStackResult
   * @description see [native-cdk](https://github.com/aws/aws-cdk/blob/master/packages/aws-cdk/lib/api/deploy-stack.ts)
   * for full reference for this interface (look for `DeployStackResult` interface in `aws-cdk`)
   */
  /**
   * @typedef {Object} PseudoCliOptions
   * @description parameters to create a cdk-web pseudo cli
   * @property {cdk.Stack} [stack] stack is optional for bootstrapping (DEFAULT: undefined)
   * @property {AWS.Credentials} [credentials] credentials is optional for synthesizing (DEFAULT: undefined)
   */
  /**
   * @typedef {Object} PseudoCliDiffOptions
   * @description parameters to execute a cli diff operation with
   * @property {string} [templatePath] template to compare current stack with (DEFAULT: "<last-template-in-cdk.out>")
   * @property {number} [contextLines] number of contexts per line (DEFAULT: 3)
   * @property {boolean} [strict] strict mode (DEFAULT: false)
   * @property {boolean} [fail] fail if differences are detected (DEFAULT: false)
   * @property {boolean} [securityOnly] only security changes to be noted (DEFAULT: false)
   * @property {boolean} [synthOptions] optional synth options passed to generate the new stack (DEFAULT: undefined)
   */
  /**
   * @typedef {Object} PseudoCliRenderOptions
   * @description parameters to execute a cli render operation with
   * @property {boolean} [synthOptions] optional synth options passed to generate the new stack (DEFAULT: undefined)
   * @property {Object} [template] HTML template to render (DEFAULT: a standalone builtin single html page)
   * @property {("html"|"vis.js")} [type] graph render type (DEFAULT: "html")
   * @see https://visjs.github.io/vis-network/docs/network/
   */
  /**
   * @typedef {Object} BootstrapEnvironmentOptionsExtra
   * @description extensions of cdk bootstrap options, adapted to suit cdk-web's needs
   * @property {string} [account] the AWS account to be bootstrapped (no-op if already done) (DEFAULT: "<account-bound-to-credentials>")
   * @property {string} [region] the AWS region in your account to be bootstrapped (DEFAULT: "us-east-1")
   * @property {Object} [cors] CORS policy on the CDK assets bucket. this is needed for cdk-web to work correctly in browser.
   * (DEFAULT: "[{"AllowedHeaders":["*"],"AllowedMethods":["HEAD","GET","POST","PUT","DELETE"],"AllowedOrigins":["*"]}]")
   * @see [native-cdk](https://github.com/aws/aws-cdk/blob/master/packages/aws-cdk/lib/api/bootstrap/bootstrap-props.ts)
   * for additional parameters acceptable for this object (look for `BootstrapEnvironmentOptions` interface in `aws-cdk`)
   *
   * @typedef {BootstrapEnvironmentOptions|BootstrapEnvironmentOptionsExtra} BootstrapWebEnvironmentOptions
   * @description parameters to bootstrap an AWS account for cdk-web
   */
  class PseudoCli {
      /**
       * > **NOTE 1:** for this to work, the cdk bucket must have a respectable CORS policy attached to it.
       * you can change the CORS policy in [ Properties > Permissions > Edit CORS Configuration ].
       * a sample policy to wildcard-allow everything looks like this:
       * > ```JSON
       * > [
       * >   {
       * >     "AllowedHeaders": ["*"],
       * >     "AllowedMethods": ["HEAD","GET","POST","PUT","DELETE"],
       * >     "AllowedOrigins": ["*"]
       * >   }
       * > ]
       * > ```
       *
       * > **NOTE 2:** Providing "credentials" is optional but you won't be able to take live actions (e.g deploy and destroy)
       * @param {PseudoCliOptions} [opts] options for cdk-web's pseudo cli (DEFAULT: undefined)
       */
      constructor(opts?: PseudoCliOptions);
      /**
       * @type {PseudoCliOptions}
       * @private
       */
      private opts;
      /**
       * just like native "cdk synth". it synthesizes your stack.
       * @param {StageSynthesisOptions} [opts] options for stack synthage (DEFAULT: undefined)
       * @returns {Promise<CloudFormationTemplate>} the cloudformation template JSON.
       * @example
       * ```JS
       * const cli = new CDK.PseudoCli({
       *   stack,
       *   credentials: {
       *     accessKeyId: "your AWS access key goes here",
       *     secretAccessKey: "your AWS secret goes here",
       *     // sessionToken: "in case you have a session token",
       *   },
       * });
       * // just like executing "cdk synth"
       * const template = await cli.synth();
       * console.log(template);
       * ```
       * @see [native-cdk](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.StageSynthesisOptions.html)
       * for additional parameters acceptable for this object (look for `StageSynthesisOptions` interface in `aws-cdk`)
       */
      synth(opts?: StageSynthesisOptions): Promise<CloudFormationTemplate>;
      /**
       * bootstraps a live AWS account and takes "special care" for cdk-web
       * @param {BootstrapWebEnvironmentOptions} [opts] options for bootstrapage (DEFAULT: undefined)
       * @returns {Promise<DeployStackResult>}
       */
      bootstrap(opts?: BootstrapWebEnvironmentOptions): Promise<DeployStackResult>;
      /**
       * detects changes between the current stack and the previous run of `synth()`
       * @note executes synth() internally to generate the new stack template
       * @param {PseudoCliDiffOptions} [options] options to execute diff with (DEFAULT: undefined)
       * @returns {Promise<void>} prints diff to console. rejects IFF "fail" is true and changes are detected
       */
      diff(options?: PseudoCliDiffOptions): Promise<void>;
      /**
       * visually renders the stack
       * @param {PseudoCliRenderOptions} [options] options to execute render with (DEFAULT: undefined)
       * @returns {Promise<string>} rendered html string for "html" type
       */
      render(options?: PseudoCliRenderOptions): Promise<string>;
      /**
       * just like native "cdk deploy". it deploys your stack to a live AWS account
       * @param {DeployStackOptions} [opts] options for stack deployage (DEFAULT: undefined)
       * @example
       * ```JS
       * const cli = new CDK.PseudoCli({stack, credentials: { ... }});
       * // just like executing "cdk deploy"
       * await cli.deploy();
       * ```
       * @see [native-cdk](https://github.com/aws/aws-cdk/blob/master/packages/aws-cdk/lib/api/deploy-stack.ts)
       * for additional parameters acceptable for this object (look for `DeployStackOptions` interface in `aws-cdk`)
       * @returns {Promise<DeployStackResult>}
       */
      deploy(opts?: DeployStackOptions): Promise<DeployStackResult>;
      /**
       * just like native "cdk destroy". it destroys your previously deployed stack in a live AWS account
       * @param {DestroyStackOptions} [opts] options for stack destroyage (DEFAULT: undefined)
       * @example
       * ```JS
       * const cli = new CDK.PseudoCli({stack, credentials: { ... }});
       * // just like executing "cdk destroy"
       * await cli.destroy();
       * ```
       * @see [native-cdk](https://github.com/aws/aws-cdk/blob/master/packages/aws-cdk/lib/api/deploy-stack.ts)
       * for additional parameters acceptable for this object (look for `DestroyStackOptions` interface in `aws-cdk`)
       * @returns {Promise<void>}
       */
      destroy(opts?: DestroyStackOptions): Promise<void>;
  }
  namespace PseudoCli {
      export { CloudFormationTemplate, DeployStackResult, PseudoCliOptions, PseudoCliDiffOptions, PseudoCliRenderOptions, BootstrapEnvironmentOptionsExtra, BootstrapWebEnvironmentOptions };
  }
  type StageSynthesisOptions = import("./types/aws-cdk-lib").StageSynthesisOptions;
  type CloudFormationTemplate = any;
  type BootstrapWebEnvironmentOptions = BootstrapEnvironmentOptions | BootstrapEnvironmentOptionsExtra;
  type DeployStackResult = any;
  type PseudoCliDiffOptions = any;
  type PseudoCliRenderOptions = any;
  type DeployStackOptions = any;
  type DestroyStackOptions = any;
  type PseudoCliOptions = any;
  type BootstrapEnvironmentOptionsExtra = any;
  type BootstrapEnvironmentOptions = any;
}
declare module 'cdk-web/entrypoint.generated' {
  /// <reference types="node" />
  const _exports: {
      PseudoCli: typeof import("cdk-web/cli");
      version: {
          constructs: string;
          "aws-cdk-lib": string;
          "aws-cdk": string;
          "cdk-web": string;
      };
      emitter: import("events").EventEmitter;
      require(name: any): NodeRequire;
      require(name: "constructs"): typeof import("./types/constructs/lib");
      require(name: "aws-cdk-lib"): typeof import("./types/aws-cdk-lib");
      require(name: "aws-cdk-lib/alexa-ask"): typeof import("./types/aws-cdk-lib/alexa-ask");
      require(name: "aws-cdk-lib/assertions/lib/helpers-internal"): typeof import("./types/aws-cdk-lib/assertions/lib/helpers-internal");
      require(name: "aws-cdk-lib/assertions"): typeof import("./types/aws-cdk-lib/assertions");
      require(name: "aws-cdk-lib/assets"): typeof import("./types/aws-cdk-lib/assets");
      require(name: "aws-cdk-lib/aws-accessanalyzer"): typeof import("./types/aws-cdk-lib/aws-accessanalyzer");
      require(name: "aws-cdk-lib/aws-acmpca"): typeof import("./types/aws-cdk-lib/aws-acmpca");
      require(name: "aws-cdk-lib/aws-amazonmq"): typeof import("./types/aws-cdk-lib/aws-amazonmq");
      require(name: "aws-cdk-lib/aws-amplify"): typeof import("./types/aws-cdk-lib/aws-amplify");
      require(name: "aws-cdk-lib/aws-amplifyuibuilder"): typeof import("./types/aws-cdk-lib/aws-amplifyuibuilder");
      require(name: "aws-cdk-lib/aws-apigateway"): typeof import("./types/aws-cdk-lib/aws-apigateway");
      require(name: "aws-cdk-lib/aws-apigatewayv2"): typeof import("./types/aws-cdk-lib/aws-apigatewayv2");
      require(name: "aws-cdk-lib/aws-appconfig"): typeof import("./types/aws-cdk-lib/aws-appconfig");
      require(name: "aws-cdk-lib/aws-appflow"): typeof import("./types/aws-cdk-lib/aws-appflow");
      require(name: "aws-cdk-lib/aws-appintegrations"): typeof import("./types/aws-cdk-lib/aws-appintegrations");
      require(name: "aws-cdk-lib/aws-applicationautoscaling"): typeof import("./types/aws-cdk-lib/aws-applicationautoscaling");
      require(name: "aws-cdk-lib/aws-applicationinsights"): typeof import("./types/aws-cdk-lib/aws-applicationinsights");
      require(name: "aws-cdk-lib/aws-appmesh"): typeof import("./types/aws-cdk-lib/aws-appmesh");
      require(name: "aws-cdk-lib/aws-apprunner"): typeof import("./types/aws-cdk-lib/aws-apprunner");
      require(name: "aws-cdk-lib/aws-appstream"): typeof import("./types/aws-cdk-lib/aws-appstream");
      require(name: "aws-cdk-lib/aws-appsync"): typeof import("./types/aws-cdk-lib/aws-appsync");
      require(name: "aws-cdk-lib/aws-aps"): typeof import("./types/aws-cdk-lib/aws-aps");
      require(name: "aws-cdk-lib/aws-athena"): typeof import("./types/aws-cdk-lib/aws-athena");
      require(name: "aws-cdk-lib/aws-auditmanager"): typeof import("./types/aws-cdk-lib/aws-auditmanager");
      require(name: "aws-cdk-lib/aws-autoscaling"): typeof import("./types/aws-cdk-lib/aws-autoscaling");
      require(name: "aws-cdk-lib/aws-autoscaling-common"): typeof import("./types/aws-cdk-lib/aws-autoscaling-common");
      require(name: "aws-cdk-lib/aws-autoscaling-hooktargets"): typeof import("./types/aws-cdk-lib/aws-autoscaling-hooktargets");
      require(name: "aws-cdk-lib/aws-autoscalingplans"): typeof import("./types/aws-cdk-lib/aws-autoscalingplans");
      require(name: "aws-cdk-lib/aws-backup"): typeof import("./types/aws-cdk-lib/aws-backup");
      require(name: "aws-cdk-lib/aws-batch"): typeof import("./types/aws-cdk-lib/aws-batch");
      require(name: "aws-cdk-lib/aws-billingconductor"): typeof import("./types/aws-cdk-lib/aws-billingconductor");
      require(name: "aws-cdk-lib/aws-budgets"): typeof import("./types/aws-cdk-lib/aws-budgets");
      require(name: "aws-cdk-lib/aws-cassandra"): typeof import("./types/aws-cdk-lib/aws-cassandra");
      require(name: "aws-cdk-lib/aws-ce"): typeof import("./types/aws-cdk-lib/aws-ce");
      require(name: "aws-cdk-lib/aws-certificatemanager"): typeof import("./types/aws-cdk-lib/aws-certificatemanager");
      require(name: "aws-cdk-lib/aws-chatbot"): typeof import("./types/aws-cdk-lib/aws-chatbot");
      require(name: "aws-cdk-lib/aws-cloud9"): typeof import("./types/aws-cdk-lib/aws-cloud9");
      require(name: "aws-cdk-lib/aws-cloudformation"): typeof import("./types/aws-cdk-lib/aws-cloudformation");
      require(name: "aws-cdk-lib/aws-cloudfront"): typeof import("./types/aws-cdk-lib/aws-cloudfront");
      require(name: "aws-cdk-lib/aws-cloudfront-origins"): typeof import("./types/aws-cdk-lib/aws-cloudfront-origins");
      require(name: "aws-cdk-lib/aws-cloudtrail"): typeof import("./types/aws-cdk-lib/aws-cloudtrail");
      require(name: "aws-cdk-lib/aws-cloudwatch"): typeof import("./types/aws-cdk-lib/aws-cloudwatch");
      require(name: "aws-cdk-lib/aws-cloudwatch-actions"): typeof import("./types/aws-cdk-lib/aws-cloudwatch-actions");
      require(name: "aws-cdk-lib/aws-codeartifact"): typeof import("./types/aws-cdk-lib/aws-codeartifact");
      require(name: "aws-cdk-lib/aws-codebuild"): typeof import("./types/aws-cdk-lib/aws-codebuild");
      require(name: "aws-cdk-lib/aws-codecommit"): typeof import("./types/aws-cdk-lib/aws-codecommit");
      require(name: "aws-cdk-lib/aws-codedeploy"): typeof import("./types/aws-cdk-lib/aws-codedeploy");
      require(name: "aws-cdk-lib/aws-codeguruprofiler"): typeof import("./types/aws-cdk-lib/aws-codeguruprofiler");
      require(name: "aws-cdk-lib/aws-codegurureviewer"): typeof import("./types/aws-cdk-lib/aws-codegurureviewer");
      require(name: "aws-cdk-lib/aws-codepipeline"): typeof import("./types/aws-cdk-lib/aws-codepipeline");
      require(name: "aws-cdk-lib/aws-codepipeline-actions"): typeof import("./types/aws-cdk-lib/aws-codepipeline-actions");
      require(name: "aws-cdk-lib/aws-codestar"): typeof import("./types/aws-cdk-lib/aws-codestar");
      require(name: "aws-cdk-lib/aws-codestarconnections"): typeof import("./types/aws-cdk-lib/aws-codestarconnections");
      require(name: "aws-cdk-lib/aws-codestarnotifications"): typeof import("./types/aws-cdk-lib/aws-codestarnotifications");
      require(name: "aws-cdk-lib/aws-cognito"): typeof import("./types/aws-cdk-lib/aws-cognito");
      require(name: "aws-cdk-lib/aws-config"): typeof import("./types/aws-cdk-lib/aws-config");
      require(name: "aws-cdk-lib/aws-connect"): typeof import("./types/aws-cdk-lib/aws-connect");
      require(name: "aws-cdk-lib/aws-cur"): typeof import("./types/aws-cdk-lib/aws-cur");
      require(name: "aws-cdk-lib/aws-customerprofiles"): typeof import("./types/aws-cdk-lib/aws-customerprofiles");
      require(name: "aws-cdk-lib/aws-databrew"): typeof import("./types/aws-cdk-lib/aws-databrew");
      require(name: "aws-cdk-lib/aws-datapipeline"): typeof import("./types/aws-cdk-lib/aws-datapipeline");
      require(name: "aws-cdk-lib/aws-datasync"): typeof import("./types/aws-cdk-lib/aws-datasync");
      require(name: "aws-cdk-lib/aws-dax"): typeof import("./types/aws-cdk-lib/aws-dax");
      require(name: "aws-cdk-lib/aws-detective"): typeof import("./types/aws-cdk-lib/aws-detective");
      require(name: "aws-cdk-lib/aws-devopsguru"): typeof import("./types/aws-cdk-lib/aws-devopsguru");
      require(name: "aws-cdk-lib/aws-directoryservice"): typeof import("./types/aws-cdk-lib/aws-directoryservice");
      require(name: "aws-cdk-lib/aws-dlm"): typeof import("./types/aws-cdk-lib/aws-dlm");
      require(name: "aws-cdk-lib/aws-dms"): typeof import("./types/aws-cdk-lib/aws-dms");
      require(name: "aws-cdk-lib/aws-docdb"): typeof import("./types/aws-cdk-lib/aws-docdb");
      require(name: "aws-cdk-lib/aws-dynamodb"): typeof import("./types/aws-cdk-lib/aws-dynamodb");
      require(name: "aws-cdk-lib/aws-ec2"): typeof import("./types/aws-cdk-lib/aws-ec2");
      require(name: "aws-cdk-lib/aws-ecr"): typeof import("./types/aws-cdk-lib/aws-ecr");
      require(name: "aws-cdk-lib/aws-ecr-assets"): typeof import("./types/aws-cdk-lib/aws-ecr-assets");
      require(name: "aws-cdk-lib/aws-ecs"): typeof import("./types/aws-cdk-lib/aws-ecs");
      require(name: "aws-cdk-lib/aws-ecs-patterns"): typeof import("./types/aws-cdk-lib/aws-ecs-patterns");
      require(name: "aws-cdk-lib/aws-efs"): typeof import("./types/aws-cdk-lib/aws-efs");
      require(name: "aws-cdk-lib/aws-eks"): typeof import("./types/aws-cdk-lib/aws-eks");
      require(name: "aws-cdk-lib/aws-elasticache"): typeof import("./types/aws-cdk-lib/aws-elasticache");
      require(name: "aws-cdk-lib/aws-elasticbeanstalk"): typeof import("./types/aws-cdk-lib/aws-elasticbeanstalk");
      require(name: "aws-cdk-lib/aws-elasticloadbalancing"): typeof import("./types/aws-cdk-lib/aws-elasticloadbalancing");
      require(name: "aws-cdk-lib/aws-elasticloadbalancingv2"): typeof import("./types/aws-cdk-lib/aws-elasticloadbalancingv2");
      require(name: "aws-cdk-lib/aws-elasticloadbalancingv2-actions"): typeof import("./types/aws-cdk-lib/aws-elasticloadbalancingv2-actions");
      require(name: "aws-cdk-lib/aws-elasticloadbalancingv2-targets"): typeof import("./types/aws-cdk-lib/aws-elasticloadbalancingv2-targets");
      require(name: "aws-cdk-lib/aws-elasticsearch"): typeof import("./types/aws-cdk-lib/aws-elasticsearch");
      require(name: "aws-cdk-lib/aws-emr"): typeof import("./types/aws-cdk-lib/aws-emr");
      require(name: "aws-cdk-lib/aws-emrcontainers"): typeof import("./types/aws-cdk-lib/aws-emrcontainers");
      require(name: "aws-cdk-lib/aws-emrserverless"): typeof import("./types/aws-cdk-lib/aws-emrserverless");
      require(name: "aws-cdk-lib/aws-events"): typeof import("./types/aws-cdk-lib/aws-events");
      require(name: "aws-cdk-lib/aws-events-targets"): typeof import("./types/aws-cdk-lib/aws-events-targets");
      require(name: "aws-cdk-lib/aws-eventschemas"): typeof import("./types/aws-cdk-lib/aws-eventschemas");
      require(name: "aws-cdk-lib/aws-evidently"): typeof import("./types/aws-cdk-lib/aws-evidently");
      require(name: "aws-cdk-lib/aws-finspace"): typeof import("./types/aws-cdk-lib/aws-finspace");
      require(name: "aws-cdk-lib/aws-fis"): typeof import("./types/aws-cdk-lib/aws-fis");
      require(name: "aws-cdk-lib/aws-fms"): typeof import("./types/aws-cdk-lib/aws-fms");
      require(name: "aws-cdk-lib/aws-forecast"): typeof import("./types/aws-cdk-lib/aws-forecast");
      require(name: "aws-cdk-lib/aws-frauddetector"): typeof import("./types/aws-cdk-lib/aws-frauddetector");
      require(name: "aws-cdk-lib/aws-fsx"): typeof import("./types/aws-cdk-lib/aws-fsx");
      require(name: "aws-cdk-lib/aws-gamelift"): typeof import("./types/aws-cdk-lib/aws-gamelift");
      require(name: "aws-cdk-lib/aws-globalaccelerator"): typeof import("./types/aws-cdk-lib/aws-globalaccelerator");
      require(name: "aws-cdk-lib/aws-globalaccelerator-endpoints"): typeof import("./types/aws-cdk-lib/aws-globalaccelerator-endpoints");
      require(name: "aws-cdk-lib/aws-glue"): typeof import("./types/aws-cdk-lib/aws-glue");
      require(name: "aws-cdk-lib/aws-greengrass"): typeof import("./types/aws-cdk-lib/aws-greengrass");
      require(name: "aws-cdk-lib/aws-greengrassv2"): typeof import("./types/aws-cdk-lib/aws-greengrassv2");
      require(name: "aws-cdk-lib/aws-groundstation"): typeof import("./types/aws-cdk-lib/aws-groundstation");
      require(name: "aws-cdk-lib/aws-guardduty"): typeof import("./types/aws-cdk-lib/aws-guardduty");
      require(name: "aws-cdk-lib/aws-healthlake"): typeof import("./types/aws-cdk-lib/aws-healthlake");
      require(name: "aws-cdk-lib/aws-iam"): typeof import("./types/aws-cdk-lib/aws-iam");
      require(name: "aws-cdk-lib/aws-imagebuilder"): typeof import("./types/aws-cdk-lib/aws-imagebuilder");
      require(name: "aws-cdk-lib/aws-inspector"): typeof import("./types/aws-cdk-lib/aws-inspector");
      require(name: "aws-cdk-lib/aws-inspectorv2"): typeof import("./types/aws-cdk-lib/aws-inspectorv2");
      require(name: "aws-cdk-lib/aws-iot"): typeof import("./types/aws-cdk-lib/aws-iot");
      require(name: "aws-cdk-lib/aws-iot1click"): typeof import("./types/aws-cdk-lib/aws-iot1click");
      require(name: "aws-cdk-lib/aws-iotanalytics"): typeof import("./types/aws-cdk-lib/aws-iotanalytics");
      require(name: "aws-cdk-lib/aws-iotcoredeviceadvisor"): typeof import("./types/aws-cdk-lib/aws-iotcoredeviceadvisor");
      require(name: "aws-cdk-lib/aws-iotevents"): typeof import("./types/aws-cdk-lib/aws-iotevents");
      require(name: "aws-cdk-lib/aws-iotfleethub"): typeof import("./types/aws-cdk-lib/aws-iotfleethub");
      require(name: "aws-cdk-lib/aws-iotsitewise"): typeof import("./types/aws-cdk-lib/aws-iotsitewise");
      require(name: "aws-cdk-lib/aws-iotthingsgraph"): typeof import("./types/aws-cdk-lib/aws-iotthingsgraph");
      require(name: "aws-cdk-lib/aws-iottwinmaker"): typeof import("./types/aws-cdk-lib/aws-iottwinmaker");
      require(name: "aws-cdk-lib/aws-iotwireless"): typeof import("./types/aws-cdk-lib/aws-iotwireless");
      require(name: "aws-cdk-lib/aws-ivs"): typeof import("./types/aws-cdk-lib/aws-ivs");
      require(name: "aws-cdk-lib/aws-kafkaconnect"): typeof import("./types/aws-cdk-lib/aws-kafkaconnect");
      require(name: "aws-cdk-lib/aws-kendra"): typeof import("./types/aws-cdk-lib/aws-kendra");
      require(name: "aws-cdk-lib/aws-kinesis"): typeof import("./types/aws-cdk-lib/aws-kinesis");
      require(name: "aws-cdk-lib/aws-kinesisanalytics"): typeof import("./types/aws-cdk-lib/aws-kinesisanalytics");
      require(name: "aws-cdk-lib/aws-kinesisanalyticsv2"): typeof import("./types/aws-cdk-lib/aws-kinesisanalyticsv2");
      require(name: "aws-cdk-lib/aws-kinesisfirehose"): typeof import("./types/aws-cdk-lib/aws-kinesisfirehose");
      require(name: "aws-cdk-lib/aws-kinesisvideo"): typeof import("./types/aws-cdk-lib/aws-kinesisvideo");
      require(name: "aws-cdk-lib/aws-kms"): typeof import("./types/aws-cdk-lib/aws-kms");
      require(name: "aws-cdk-lib/aws-lakeformation"): typeof import("./types/aws-cdk-lib/aws-lakeformation");
      require(name: "aws-cdk-lib/aws-lambda"): typeof import("./types/aws-cdk-lib/aws-lambda");
      require(name: "aws-cdk-lib/aws-lambda-destinations"): typeof import("./types/aws-cdk-lib/aws-lambda-destinations");
      require(name: "aws-cdk-lib/aws-lambda-event-sources"): typeof import("./types/aws-cdk-lib/aws-lambda-event-sources");
      require(name: "aws-cdk-lib/aws-lambda-nodejs"): typeof import("./types/aws-cdk-lib/aws-lambda-nodejs");
      require(name: "aws-cdk-lib/aws-lex"): typeof import("./types/aws-cdk-lib/aws-lex");
      require(name: "aws-cdk-lib/aws-licensemanager"): typeof import("./types/aws-cdk-lib/aws-licensemanager");
      require(name: "aws-cdk-lib/aws-lightsail"): typeof import("./types/aws-cdk-lib/aws-lightsail");
      require(name: "aws-cdk-lib/aws-location"): typeof import("./types/aws-cdk-lib/aws-location");
      require(name: "aws-cdk-lib/aws-logs"): typeof import("./types/aws-cdk-lib/aws-logs");
      require(name: "aws-cdk-lib/aws-logs-destinations"): typeof import("./types/aws-cdk-lib/aws-logs-destinations");
      require(name: "aws-cdk-lib/aws-lookoutequipment"): typeof import("./types/aws-cdk-lib/aws-lookoutequipment");
      require(name: "aws-cdk-lib/aws-lookoutmetrics"): typeof import("./types/aws-cdk-lib/aws-lookoutmetrics");
      require(name: "aws-cdk-lib/aws-lookoutvision"): typeof import("./types/aws-cdk-lib/aws-lookoutvision");
      require(name: "aws-cdk-lib/aws-macie"): typeof import("./types/aws-cdk-lib/aws-macie");
      require(name: "aws-cdk-lib/aws-managedblockchain"): typeof import("./types/aws-cdk-lib/aws-managedblockchain");
      require(name: "aws-cdk-lib/aws-mediaconnect"): typeof import("./types/aws-cdk-lib/aws-mediaconnect");
      require(name: "aws-cdk-lib/aws-mediaconvert"): typeof import("./types/aws-cdk-lib/aws-mediaconvert");
      require(name: "aws-cdk-lib/aws-medialive"): typeof import("./types/aws-cdk-lib/aws-medialive");
      require(name: "aws-cdk-lib/aws-mediapackage"): typeof import("./types/aws-cdk-lib/aws-mediapackage");
      require(name: "aws-cdk-lib/aws-mediastore"): typeof import("./types/aws-cdk-lib/aws-mediastore");
      require(name: "aws-cdk-lib/aws-mediatailor"): typeof import("./types/aws-cdk-lib/aws-mediatailor");
      require(name: "aws-cdk-lib/aws-memorydb"): typeof import("./types/aws-cdk-lib/aws-memorydb");
      require(name: "aws-cdk-lib/aws-msk"): typeof import("./types/aws-cdk-lib/aws-msk");
      require(name: "aws-cdk-lib/aws-mwaa"): typeof import("./types/aws-cdk-lib/aws-mwaa");
      require(name: "aws-cdk-lib/aws-neptune"): typeof import("./types/aws-cdk-lib/aws-neptune");
      require(name: "aws-cdk-lib/aws-networkfirewall"): typeof import("./types/aws-cdk-lib/aws-networkfirewall");
      require(name: "aws-cdk-lib/aws-networkmanager"): typeof import("./types/aws-cdk-lib/aws-networkmanager");
      require(name: "aws-cdk-lib/aws-nimblestudio"): typeof import("./types/aws-cdk-lib/aws-nimblestudio");
      require(name: "aws-cdk-lib/aws-opensearchservice"): typeof import("./types/aws-cdk-lib/aws-opensearchservice");
      require(name: "aws-cdk-lib/aws-opsworks"): typeof import("./types/aws-cdk-lib/aws-opsworks");
      require(name: "aws-cdk-lib/aws-opsworkscm"): typeof import("./types/aws-cdk-lib/aws-opsworkscm");
      require(name: "aws-cdk-lib/aws-panorama"): typeof import("./types/aws-cdk-lib/aws-panorama");
      require(name: "aws-cdk-lib/aws-personalize"): typeof import("./types/aws-cdk-lib/aws-personalize");
      require(name: "aws-cdk-lib/aws-pinpoint"): typeof import("./types/aws-cdk-lib/aws-pinpoint");
      require(name: "aws-cdk-lib/aws-pinpointemail"): typeof import("./types/aws-cdk-lib/aws-pinpointemail");
      require(name: "aws-cdk-lib/aws-qldb"): typeof import("./types/aws-cdk-lib/aws-qldb");
      require(name: "aws-cdk-lib/aws-quicksight"): typeof import("./types/aws-cdk-lib/aws-quicksight");
      require(name: "aws-cdk-lib/aws-ram"): typeof import("./types/aws-cdk-lib/aws-ram");
      require(name: "aws-cdk-lib/aws-rds"): typeof import("./types/aws-cdk-lib/aws-rds");
      require(name: "aws-cdk-lib/aws-redshift"): typeof import("./types/aws-cdk-lib/aws-redshift");
      require(name: "aws-cdk-lib/aws-redshiftserverless"): typeof import("./types/aws-cdk-lib/aws-redshiftserverless");
      require(name: "aws-cdk-lib/aws-refactorspaces"): typeof import("./types/aws-cdk-lib/aws-refactorspaces");
      require(name: "aws-cdk-lib/aws-rekognition"): typeof import("./types/aws-cdk-lib/aws-rekognition");
      require(name: "aws-cdk-lib/aws-resiliencehub"): typeof import("./types/aws-cdk-lib/aws-resiliencehub");
      require(name: "aws-cdk-lib/aws-resourcegroups"): typeof import("./types/aws-cdk-lib/aws-resourcegroups");
      require(name: "aws-cdk-lib/aws-robomaker"): typeof import("./types/aws-cdk-lib/aws-robomaker");
      require(name: "aws-cdk-lib/aws-route53"): typeof import("./types/aws-cdk-lib/aws-route53");
      require(name: "aws-cdk-lib/aws-route53-patterns"): typeof import("./types/aws-cdk-lib/aws-route53-patterns");
      require(name: "aws-cdk-lib/aws-route53-targets"): typeof import("./types/aws-cdk-lib/aws-route53-targets");
      require(name: "aws-cdk-lib/aws-route53recoverycontrol"): typeof import("./types/aws-cdk-lib/aws-route53recoverycontrol");
      require(name: "aws-cdk-lib/aws-route53recoveryreadiness"): typeof import("./types/aws-cdk-lib/aws-route53recoveryreadiness");
      require(name: "aws-cdk-lib/aws-route53resolver"): typeof import("./types/aws-cdk-lib/aws-route53resolver");
      require(name: "aws-cdk-lib/aws-rum"): typeof import("./types/aws-cdk-lib/aws-rum");
      require(name: "aws-cdk-lib/aws-s3"): typeof import("./types/aws-cdk-lib/aws-s3");
      require(name: "aws-cdk-lib/aws-s3-assets"): typeof import("./types/aws-cdk-lib/aws-s3-assets");
      require(name: "aws-cdk-lib/aws-s3-deployment"): typeof import("./types/aws-cdk-lib/aws-s3-deployment");
      require(name: "aws-cdk-lib/aws-s3-notifications"): typeof import("./types/aws-cdk-lib/aws-s3-notifications");
      require(name: "aws-cdk-lib/aws-s3objectlambda"): typeof import("./types/aws-cdk-lib/aws-s3objectlambda");
      require(name: "aws-cdk-lib/aws-s3outposts"): typeof import("./types/aws-cdk-lib/aws-s3outposts");
      require(name: "aws-cdk-lib/aws-sagemaker"): typeof import("./types/aws-cdk-lib/aws-sagemaker");
      require(name: "aws-cdk-lib/aws-sam"): typeof import("./types/aws-cdk-lib/aws-sam");
      require(name: "aws-cdk-lib/aws-sdb"): typeof import("./types/aws-cdk-lib/aws-sdb");
      require(name: "aws-cdk-lib/aws-secretsmanager"): typeof import("./types/aws-cdk-lib/aws-secretsmanager");
      require(name: "aws-cdk-lib/aws-securityhub"): typeof import("./types/aws-cdk-lib/aws-securityhub");
      require(name: "aws-cdk-lib/aws-servicecatalog"): typeof import("./types/aws-cdk-lib/aws-servicecatalog");
      require(name: "aws-cdk-lib/aws-servicecatalogappregistry"): typeof import("./types/aws-cdk-lib/aws-servicecatalogappregistry");
      require(name: "aws-cdk-lib/aws-servicediscovery"): typeof import("./types/aws-cdk-lib/aws-servicediscovery");
      require(name: "aws-cdk-lib/aws-ses"): typeof import("./types/aws-cdk-lib/aws-ses");
      require(name: "aws-cdk-lib/aws-ses-actions"): typeof import("./types/aws-cdk-lib/aws-ses-actions");
      require(name: "aws-cdk-lib/aws-signer"): typeof import("./types/aws-cdk-lib/aws-signer");
      require(name: "aws-cdk-lib/aws-sns"): typeof import("./types/aws-cdk-lib/aws-sns");
      require(name: "aws-cdk-lib/aws-sns-subscriptions"): typeof import("./types/aws-cdk-lib/aws-sns-subscriptions");
      require(name: "aws-cdk-lib/aws-sqs"): typeof import("./types/aws-cdk-lib/aws-sqs");
      require(name: "aws-cdk-lib/aws-ssm"): typeof import("./types/aws-cdk-lib/aws-ssm");
      require(name: "aws-cdk-lib/aws-ssmcontacts"): typeof import("./types/aws-cdk-lib/aws-ssmcontacts");
      require(name: "aws-cdk-lib/aws-ssmincidents"): typeof import("./types/aws-cdk-lib/aws-ssmincidents");
      require(name: "aws-cdk-lib/aws-sso"): typeof import("./types/aws-cdk-lib/aws-sso");
      require(name: "aws-cdk-lib/aws-stepfunctions"): typeof import("./types/aws-cdk-lib/aws-stepfunctions");
      require(name: "aws-cdk-lib/aws-stepfunctions-tasks"): typeof import("./types/aws-cdk-lib/aws-stepfunctions-tasks");
      require(name: "aws-cdk-lib/aws-synthetics"): typeof import("./types/aws-cdk-lib/aws-synthetics");
      require(name: "aws-cdk-lib/aws-timestream"): typeof import("./types/aws-cdk-lib/aws-timestream");
      require(name: "aws-cdk-lib/aws-transfer"): typeof import("./types/aws-cdk-lib/aws-transfer");
      require(name: "aws-cdk-lib/aws-voiceid"): typeof import("./types/aws-cdk-lib/aws-voiceid");
      require(name: "aws-cdk-lib/aws-waf"): typeof import("./types/aws-cdk-lib/aws-waf");
      require(name: "aws-cdk-lib/aws-wafregional"): typeof import("./types/aws-cdk-lib/aws-wafregional");
      require(name: "aws-cdk-lib/aws-wafv2"): typeof import("./types/aws-cdk-lib/aws-wafv2");
      require(name: "aws-cdk-lib/aws-wisdom"): typeof import("./types/aws-cdk-lib/aws-wisdom");
      require(name: "aws-cdk-lib/aws-workspaces"): typeof import("./types/aws-cdk-lib/aws-workspaces");
      require(name: "aws-cdk-lib/aws-xray"): typeof import("./types/aws-cdk-lib/aws-xray");
      require(name: "aws-cdk-lib/cloud-assembly-schema"): typeof import("./types/aws-cdk-lib/cloud-assembly-schema");
      require(name: "aws-cdk-lib/cloudformation-include"): typeof import("./types/aws-cdk-lib/cloudformation-include");
      require(name: "aws-cdk-lib/core/lib/helpers-internal"): typeof import("./types/aws-cdk-lib/core/lib/helpers-internal");
      require(name: "aws-cdk-lib/cx-api"): typeof import("./types/aws-cdk-lib/cx-api");
      require(name: "aws-cdk-lib/lambda-layer-awscli"): typeof import("./types/aws-cdk-lib/lambda-layer-awscli");
      require(name: "aws-cdk-lib/lambda-layer-kubectl"): typeof import("./types/aws-cdk-lib/lambda-layer-kubectl");
      require(name: "aws-cdk-lib/lambda-layer-node-proxy-agent"): typeof import("./types/aws-cdk-lib/lambda-layer-node-proxy-agent");
      require(name: "aws-cdk-lib/pipelines"): typeof import("./types/aws-cdk-lib/pipelines");
      require(name: "aws-cdk-lib/pipelines/lib/helpers-internal"): typeof import("./types/aws-cdk-lib/pipelines/lib/helpers-internal");
      require(name: "aws-cdk-lib/region-info"): typeof import("./types/aws-cdk-lib/region-info");
      require(name: "aws-cdk-lib/triggers"): typeof import("./types/aws-cdk-lib/triggers");
      init: () => void;
      free: () => void;
      dump: () => any;
      path: import("path").PlatformPath;
      process: NodeJS.Process;
      constructs: typeof import("./types/constructs/lib");
      'aws-cdk-lib': typeof import("./types/aws-cdk-lib");
      'aws-cdk-lib/alexa-ask': typeof import("./types/aws-cdk-lib/alexa-ask");
      'aws-cdk-lib/assertions/lib/helpers-internal': typeof import("./types/aws-cdk-lib/assertions/lib/helpers-internal");
      'aws-cdk-lib/assertions': typeof import("./types/aws-cdk-lib/assertions");
      'aws-cdk-lib/assets': typeof import("./types/aws-cdk-lib/assets");
      'aws-cdk-lib/aws-accessanalyzer': typeof import("./types/aws-cdk-lib/aws-accessanalyzer");
      'aws-cdk-lib/aws-acmpca': typeof import("./types/aws-cdk-lib/aws-acmpca");
      'aws-cdk-lib/aws-amazonmq': typeof import("./types/aws-cdk-lib/aws-amazonmq");
      'aws-cdk-lib/aws-amplify': typeof import("./types/aws-cdk-lib/aws-amplify");
      'aws-cdk-lib/aws-amplifyuibuilder': typeof import("./types/aws-cdk-lib/aws-amplifyuibuilder");
      'aws-cdk-lib/aws-apigateway': typeof import("./types/aws-cdk-lib/aws-apigateway");
      'aws-cdk-lib/aws-apigatewayv2': typeof import("./types/aws-cdk-lib/aws-apigatewayv2");
      'aws-cdk-lib/aws-appconfig': typeof import("./types/aws-cdk-lib/aws-appconfig");
      'aws-cdk-lib/aws-appflow': typeof import("./types/aws-cdk-lib/aws-appflow");
      'aws-cdk-lib/aws-appintegrations': typeof import("./types/aws-cdk-lib/aws-appintegrations");
      'aws-cdk-lib/aws-applicationautoscaling': typeof import("./types/aws-cdk-lib/aws-applicationautoscaling");
      'aws-cdk-lib/aws-applicationinsights': typeof import("./types/aws-cdk-lib/aws-applicationinsights");
      'aws-cdk-lib/aws-appmesh': typeof import("./types/aws-cdk-lib/aws-appmesh");
      'aws-cdk-lib/aws-apprunner': typeof import("./types/aws-cdk-lib/aws-apprunner");
      'aws-cdk-lib/aws-appstream': typeof import("./types/aws-cdk-lib/aws-appstream");
      'aws-cdk-lib/aws-appsync': typeof import("./types/aws-cdk-lib/aws-appsync");
      'aws-cdk-lib/aws-aps': typeof import("./types/aws-cdk-lib/aws-aps");
      'aws-cdk-lib/aws-athena': typeof import("./types/aws-cdk-lib/aws-athena");
      'aws-cdk-lib/aws-auditmanager': typeof import("./types/aws-cdk-lib/aws-auditmanager");
      'aws-cdk-lib/aws-autoscaling': typeof import("./types/aws-cdk-lib/aws-autoscaling");
      'aws-cdk-lib/aws-autoscaling-common': typeof import("./types/aws-cdk-lib/aws-autoscaling-common");
      'aws-cdk-lib/aws-autoscaling-hooktargets': typeof import("./types/aws-cdk-lib/aws-autoscaling-hooktargets");
      'aws-cdk-lib/aws-autoscalingplans': typeof import("./types/aws-cdk-lib/aws-autoscalingplans");
      'aws-cdk-lib/aws-backup': typeof import("./types/aws-cdk-lib/aws-backup");
      'aws-cdk-lib/aws-batch': typeof import("./types/aws-cdk-lib/aws-batch");
      'aws-cdk-lib/aws-billingconductor': typeof import("./types/aws-cdk-lib/aws-billingconductor");
      'aws-cdk-lib/aws-budgets': typeof import("./types/aws-cdk-lib/aws-budgets");
      'aws-cdk-lib/aws-cassandra': typeof import("./types/aws-cdk-lib/aws-cassandra");
      'aws-cdk-lib/aws-ce': typeof import("./types/aws-cdk-lib/aws-ce");
      'aws-cdk-lib/aws-certificatemanager': typeof import("./types/aws-cdk-lib/aws-certificatemanager");
      'aws-cdk-lib/aws-chatbot': typeof import("./types/aws-cdk-lib/aws-chatbot");
      'aws-cdk-lib/aws-cloud9': typeof import("./types/aws-cdk-lib/aws-cloud9");
      'aws-cdk-lib/aws-cloudformation': typeof import("./types/aws-cdk-lib/aws-cloudformation");
      'aws-cdk-lib/aws-cloudfront': typeof import("./types/aws-cdk-lib/aws-cloudfront");
      'aws-cdk-lib/aws-cloudfront-origins': typeof import("./types/aws-cdk-lib/aws-cloudfront-origins");
      'aws-cdk-lib/aws-cloudtrail': typeof import("./types/aws-cdk-lib/aws-cloudtrail");
      'aws-cdk-lib/aws-cloudwatch': typeof import("./types/aws-cdk-lib/aws-cloudwatch");
      'aws-cdk-lib/aws-cloudwatch-actions': typeof import("./types/aws-cdk-lib/aws-cloudwatch-actions");
      'aws-cdk-lib/aws-codeartifact': typeof import("./types/aws-cdk-lib/aws-codeartifact");
      'aws-cdk-lib/aws-codebuild': typeof import("./types/aws-cdk-lib/aws-codebuild");
      'aws-cdk-lib/aws-codecommit': typeof import("./types/aws-cdk-lib/aws-codecommit");
      'aws-cdk-lib/aws-codedeploy': typeof import("./types/aws-cdk-lib/aws-codedeploy");
      'aws-cdk-lib/aws-codeguruprofiler': typeof import("./types/aws-cdk-lib/aws-codeguruprofiler");
      'aws-cdk-lib/aws-codegurureviewer': typeof import("./types/aws-cdk-lib/aws-codegurureviewer");
      'aws-cdk-lib/aws-codepipeline': typeof import("./types/aws-cdk-lib/aws-codepipeline");
      'aws-cdk-lib/aws-codepipeline-actions': typeof import("./types/aws-cdk-lib/aws-codepipeline-actions");
      'aws-cdk-lib/aws-codestar': typeof import("./types/aws-cdk-lib/aws-codestar");
      'aws-cdk-lib/aws-codestarconnections': typeof import("./types/aws-cdk-lib/aws-codestarconnections");
      'aws-cdk-lib/aws-codestarnotifications': typeof import("./types/aws-cdk-lib/aws-codestarnotifications");
      'aws-cdk-lib/aws-cognito': typeof import("./types/aws-cdk-lib/aws-cognito");
      'aws-cdk-lib/aws-config': typeof import("./types/aws-cdk-lib/aws-config");
      'aws-cdk-lib/aws-connect': typeof import("./types/aws-cdk-lib/aws-connect");
      'aws-cdk-lib/aws-cur': typeof import("./types/aws-cdk-lib/aws-cur");
      'aws-cdk-lib/aws-customerprofiles': typeof import("./types/aws-cdk-lib/aws-customerprofiles");
      'aws-cdk-lib/aws-databrew': typeof import("./types/aws-cdk-lib/aws-databrew");
      'aws-cdk-lib/aws-datapipeline': typeof import("./types/aws-cdk-lib/aws-datapipeline");
      'aws-cdk-lib/aws-datasync': typeof import("./types/aws-cdk-lib/aws-datasync");
      'aws-cdk-lib/aws-dax': typeof import("./types/aws-cdk-lib/aws-dax");
      'aws-cdk-lib/aws-detective': typeof import("./types/aws-cdk-lib/aws-detective");
      'aws-cdk-lib/aws-devopsguru': typeof import("./types/aws-cdk-lib/aws-devopsguru");
      'aws-cdk-lib/aws-directoryservice': typeof import("./types/aws-cdk-lib/aws-directoryservice");
      'aws-cdk-lib/aws-dlm': typeof import("./types/aws-cdk-lib/aws-dlm");
      'aws-cdk-lib/aws-dms': typeof import("./types/aws-cdk-lib/aws-dms");
      'aws-cdk-lib/aws-docdb': typeof import("./types/aws-cdk-lib/aws-docdb");
      'aws-cdk-lib/aws-dynamodb': typeof import("./types/aws-cdk-lib/aws-dynamodb");
      'aws-cdk-lib/aws-ec2': typeof import("./types/aws-cdk-lib/aws-ec2");
      'aws-cdk-lib/aws-ecr': typeof import("./types/aws-cdk-lib/aws-ecr");
      'aws-cdk-lib/aws-ecr-assets': typeof import("./types/aws-cdk-lib/aws-ecr-assets");
      'aws-cdk-lib/aws-ecs': typeof import("./types/aws-cdk-lib/aws-ecs");
      'aws-cdk-lib/aws-ecs-patterns': typeof import("./types/aws-cdk-lib/aws-ecs-patterns");
      'aws-cdk-lib/aws-efs': typeof import("./types/aws-cdk-lib/aws-efs");
      'aws-cdk-lib/aws-eks': typeof import("./types/aws-cdk-lib/aws-eks");
      'aws-cdk-lib/aws-elasticache': typeof import("./types/aws-cdk-lib/aws-elasticache");
      'aws-cdk-lib/aws-elasticbeanstalk': typeof import("./types/aws-cdk-lib/aws-elasticbeanstalk");
      'aws-cdk-lib/aws-elasticloadbalancing': typeof import("./types/aws-cdk-lib/aws-elasticloadbalancing");
      'aws-cdk-lib/aws-elasticloadbalancingv2': typeof import("./types/aws-cdk-lib/aws-elasticloadbalancingv2");
      'aws-cdk-lib/aws-elasticloadbalancingv2-actions': typeof import("./types/aws-cdk-lib/aws-elasticloadbalancingv2-actions");
      'aws-cdk-lib/aws-elasticloadbalancingv2-targets': typeof import("./types/aws-cdk-lib/aws-elasticloadbalancingv2-targets");
      'aws-cdk-lib/aws-elasticsearch': typeof import("./types/aws-cdk-lib/aws-elasticsearch");
      'aws-cdk-lib/aws-emr': typeof import("./types/aws-cdk-lib/aws-emr");
      'aws-cdk-lib/aws-emrcontainers': typeof import("./types/aws-cdk-lib/aws-emrcontainers");
      'aws-cdk-lib/aws-emrserverless': typeof import("./types/aws-cdk-lib/aws-emrserverless");
      'aws-cdk-lib/aws-events': typeof import("./types/aws-cdk-lib/aws-events");
      'aws-cdk-lib/aws-events-targets': typeof import("./types/aws-cdk-lib/aws-events-targets");
      'aws-cdk-lib/aws-eventschemas': typeof import("./types/aws-cdk-lib/aws-eventschemas");
      'aws-cdk-lib/aws-evidently': typeof import("./types/aws-cdk-lib/aws-evidently");
      'aws-cdk-lib/aws-finspace': typeof import("./types/aws-cdk-lib/aws-finspace");
      'aws-cdk-lib/aws-fis': typeof import("./types/aws-cdk-lib/aws-fis");
      'aws-cdk-lib/aws-fms': typeof import("./types/aws-cdk-lib/aws-fms");
      'aws-cdk-lib/aws-forecast': typeof import("./types/aws-cdk-lib/aws-forecast");
      'aws-cdk-lib/aws-frauddetector': typeof import("./types/aws-cdk-lib/aws-frauddetector");
      'aws-cdk-lib/aws-fsx': typeof import("./types/aws-cdk-lib/aws-fsx");
      'aws-cdk-lib/aws-gamelift': typeof import("./types/aws-cdk-lib/aws-gamelift");
      'aws-cdk-lib/aws-globalaccelerator': typeof import("./types/aws-cdk-lib/aws-globalaccelerator");
      'aws-cdk-lib/aws-globalaccelerator-endpoints': typeof import("./types/aws-cdk-lib/aws-globalaccelerator-endpoints");
      'aws-cdk-lib/aws-glue': typeof import("./types/aws-cdk-lib/aws-glue");
      'aws-cdk-lib/aws-greengrass': typeof import("./types/aws-cdk-lib/aws-greengrass");
      'aws-cdk-lib/aws-greengrassv2': typeof import("./types/aws-cdk-lib/aws-greengrassv2");
      'aws-cdk-lib/aws-groundstation': typeof import("./types/aws-cdk-lib/aws-groundstation");
      'aws-cdk-lib/aws-guardduty': typeof import("./types/aws-cdk-lib/aws-guardduty");
      'aws-cdk-lib/aws-healthlake': typeof import("./types/aws-cdk-lib/aws-healthlake");
      'aws-cdk-lib/aws-iam': typeof import("./types/aws-cdk-lib/aws-iam");
      'aws-cdk-lib/aws-imagebuilder': typeof import("./types/aws-cdk-lib/aws-imagebuilder");
      'aws-cdk-lib/aws-inspector': typeof import("./types/aws-cdk-lib/aws-inspector");
      'aws-cdk-lib/aws-inspectorv2': typeof import("./types/aws-cdk-lib/aws-inspectorv2");
      'aws-cdk-lib/aws-iot': typeof import("./types/aws-cdk-lib/aws-iot");
      'aws-cdk-lib/aws-iot1click': typeof import("./types/aws-cdk-lib/aws-iot1click");
      'aws-cdk-lib/aws-iotanalytics': typeof import("./types/aws-cdk-lib/aws-iotanalytics");
      'aws-cdk-lib/aws-iotcoredeviceadvisor': typeof import("./types/aws-cdk-lib/aws-iotcoredeviceadvisor");
      'aws-cdk-lib/aws-iotevents': typeof import("./types/aws-cdk-lib/aws-iotevents");
      'aws-cdk-lib/aws-iotfleethub': typeof import("./types/aws-cdk-lib/aws-iotfleethub");
      'aws-cdk-lib/aws-iotsitewise': typeof import("./types/aws-cdk-lib/aws-iotsitewise");
      'aws-cdk-lib/aws-iotthingsgraph': typeof import("./types/aws-cdk-lib/aws-iotthingsgraph");
      'aws-cdk-lib/aws-iottwinmaker': typeof import("./types/aws-cdk-lib/aws-iottwinmaker");
      'aws-cdk-lib/aws-iotwireless': typeof import("./types/aws-cdk-lib/aws-iotwireless");
      'aws-cdk-lib/aws-ivs': typeof import("./types/aws-cdk-lib/aws-ivs");
      'aws-cdk-lib/aws-kafkaconnect': typeof import("./types/aws-cdk-lib/aws-kafkaconnect");
      'aws-cdk-lib/aws-kendra': typeof import("./types/aws-cdk-lib/aws-kendra");
      'aws-cdk-lib/aws-kinesis': typeof import("./types/aws-cdk-lib/aws-kinesis");
      'aws-cdk-lib/aws-kinesisanalytics': typeof import("./types/aws-cdk-lib/aws-kinesisanalytics");
      'aws-cdk-lib/aws-kinesisanalyticsv2': typeof import("./types/aws-cdk-lib/aws-kinesisanalyticsv2");
      'aws-cdk-lib/aws-kinesisfirehose': typeof import("./types/aws-cdk-lib/aws-kinesisfirehose");
      'aws-cdk-lib/aws-kinesisvideo': typeof import("./types/aws-cdk-lib/aws-kinesisvideo");
      'aws-cdk-lib/aws-kms': typeof import("./types/aws-cdk-lib/aws-kms");
      'aws-cdk-lib/aws-lakeformation': typeof import("./types/aws-cdk-lib/aws-lakeformation");
      'aws-cdk-lib/aws-lambda': typeof import("./types/aws-cdk-lib/aws-lambda");
      'aws-cdk-lib/aws-lambda-destinations': typeof import("./types/aws-cdk-lib/aws-lambda-destinations");
      'aws-cdk-lib/aws-lambda-event-sources': typeof import("./types/aws-cdk-lib/aws-lambda-event-sources");
      'aws-cdk-lib/aws-lambda-nodejs': typeof import("./types/aws-cdk-lib/aws-lambda-nodejs");
      'aws-cdk-lib/aws-lex': typeof import("./types/aws-cdk-lib/aws-lex");
      'aws-cdk-lib/aws-licensemanager': typeof import("./types/aws-cdk-lib/aws-licensemanager");
      'aws-cdk-lib/aws-lightsail': typeof import("./types/aws-cdk-lib/aws-lightsail");
      'aws-cdk-lib/aws-location': typeof import("./types/aws-cdk-lib/aws-location");
      'aws-cdk-lib/aws-logs': typeof import("./types/aws-cdk-lib/aws-logs");
      'aws-cdk-lib/aws-logs-destinations': typeof import("./types/aws-cdk-lib/aws-logs-destinations");
      'aws-cdk-lib/aws-lookoutequipment': typeof import("./types/aws-cdk-lib/aws-lookoutequipment");
      'aws-cdk-lib/aws-lookoutmetrics': typeof import("./types/aws-cdk-lib/aws-lookoutmetrics");
      'aws-cdk-lib/aws-lookoutvision': typeof import("./types/aws-cdk-lib/aws-lookoutvision");
      'aws-cdk-lib/aws-macie': typeof import("./types/aws-cdk-lib/aws-macie");
      'aws-cdk-lib/aws-managedblockchain': typeof import("./types/aws-cdk-lib/aws-managedblockchain");
      'aws-cdk-lib/aws-mediaconnect': typeof import("./types/aws-cdk-lib/aws-mediaconnect");
      'aws-cdk-lib/aws-mediaconvert': typeof import("./types/aws-cdk-lib/aws-mediaconvert");
      'aws-cdk-lib/aws-medialive': typeof import("./types/aws-cdk-lib/aws-medialive");
      'aws-cdk-lib/aws-mediapackage': typeof import("./types/aws-cdk-lib/aws-mediapackage");
      'aws-cdk-lib/aws-mediastore': typeof import("./types/aws-cdk-lib/aws-mediastore");
      'aws-cdk-lib/aws-mediatailor': typeof import("./types/aws-cdk-lib/aws-mediatailor");
      'aws-cdk-lib/aws-memorydb': typeof import("./types/aws-cdk-lib/aws-memorydb");
      'aws-cdk-lib/aws-msk': typeof import("./types/aws-cdk-lib/aws-msk");
      'aws-cdk-lib/aws-mwaa': typeof import("./types/aws-cdk-lib/aws-mwaa");
      'aws-cdk-lib/aws-neptune': typeof import("./types/aws-cdk-lib/aws-neptune");
      'aws-cdk-lib/aws-networkfirewall': typeof import("./types/aws-cdk-lib/aws-networkfirewall");
      'aws-cdk-lib/aws-networkmanager': typeof import("./types/aws-cdk-lib/aws-networkmanager");
      'aws-cdk-lib/aws-nimblestudio': typeof import("./types/aws-cdk-lib/aws-nimblestudio");
      'aws-cdk-lib/aws-opensearchservice': typeof import("./types/aws-cdk-lib/aws-opensearchservice");
      'aws-cdk-lib/aws-opsworks': typeof import("./types/aws-cdk-lib/aws-opsworks");
      'aws-cdk-lib/aws-opsworkscm': typeof import("./types/aws-cdk-lib/aws-opsworkscm");
      'aws-cdk-lib/aws-panorama': typeof import("./types/aws-cdk-lib/aws-panorama");
      'aws-cdk-lib/aws-personalize': typeof import("./types/aws-cdk-lib/aws-personalize");
      'aws-cdk-lib/aws-pinpoint': typeof import("./types/aws-cdk-lib/aws-pinpoint");
      'aws-cdk-lib/aws-pinpointemail': typeof import("./types/aws-cdk-lib/aws-pinpointemail");
      'aws-cdk-lib/aws-qldb': typeof import("./types/aws-cdk-lib/aws-qldb");
      'aws-cdk-lib/aws-quicksight': typeof import("./types/aws-cdk-lib/aws-quicksight");
      'aws-cdk-lib/aws-ram': typeof import("./types/aws-cdk-lib/aws-ram");
      'aws-cdk-lib/aws-rds': typeof import("./types/aws-cdk-lib/aws-rds");
      'aws-cdk-lib/aws-redshift': typeof import("./types/aws-cdk-lib/aws-redshift");
      'aws-cdk-lib/aws-redshiftserverless': typeof import("./types/aws-cdk-lib/aws-redshiftserverless");
      'aws-cdk-lib/aws-refactorspaces': typeof import("./types/aws-cdk-lib/aws-refactorspaces");
      'aws-cdk-lib/aws-rekognition': typeof import("./types/aws-cdk-lib/aws-rekognition");
      'aws-cdk-lib/aws-resiliencehub': typeof import("./types/aws-cdk-lib/aws-resiliencehub");
      'aws-cdk-lib/aws-resourcegroups': typeof import("./types/aws-cdk-lib/aws-resourcegroups");
      'aws-cdk-lib/aws-robomaker': typeof import("./types/aws-cdk-lib/aws-robomaker");
      'aws-cdk-lib/aws-route53': typeof import("./types/aws-cdk-lib/aws-route53");
      'aws-cdk-lib/aws-route53-patterns': typeof import("./types/aws-cdk-lib/aws-route53-patterns");
      'aws-cdk-lib/aws-route53-targets': typeof import("./types/aws-cdk-lib/aws-route53-targets");
      'aws-cdk-lib/aws-route53recoverycontrol': typeof import("./types/aws-cdk-lib/aws-route53recoverycontrol");
      'aws-cdk-lib/aws-route53recoveryreadiness': typeof import("./types/aws-cdk-lib/aws-route53recoveryreadiness");
      'aws-cdk-lib/aws-route53resolver': typeof import("./types/aws-cdk-lib/aws-route53resolver");
      'aws-cdk-lib/aws-rum': typeof import("./types/aws-cdk-lib/aws-rum");
      'aws-cdk-lib/aws-s3': typeof import("./types/aws-cdk-lib/aws-s3");
      'aws-cdk-lib/aws-s3-assets': typeof import("./types/aws-cdk-lib/aws-s3-assets");
      'aws-cdk-lib/aws-s3-deployment': typeof import("./types/aws-cdk-lib/aws-s3-deployment");
      'aws-cdk-lib/aws-s3-notifications': typeof import("./types/aws-cdk-lib/aws-s3-notifications");
      'aws-cdk-lib/aws-s3objectlambda': typeof import("./types/aws-cdk-lib/aws-s3objectlambda");
      'aws-cdk-lib/aws-s3outposts': typeof import("./types/aws-cdk-lib/aws-s3outposts");
      'aws-cdk-lib/aws-sagemaker': typeof import("./types/aws-cdk-lib/aws-sagemaker");
      'aws-cdk-lib/aws-sam': typeof import("./types/aws-cdk-lib/aws-sam");
      'aws-cdk-lib/aws-sdb': typeof import("./types/aws-cdk-lib/aws-sdb");
      'aws-cdk-lib/aws-secretsmanager': typeof import("./types/aws-cdk-lib/aws-secretsmanager");
      'aws-cdk-lib/aws-securityhub': typeof import("./types/aws-cdk-lib/aws-securityhub");
      'aws-cdk-lib/aws-servicecatalog': typeof import("./types/aws-cdk-lib/aws-servicecatalog");
      'aws-cdk-lib/aws-servicecatalogappregistry': typeof import("./types/aws-cdk-lib/aws-servicecatalogappregistry");
      'aws-cdk-lib/aws-servicediscovery': typeof import("./types/aws-cdk-lib/aws-servicediscovery");
      'aws-cdk-lib/aws-ses': typeof import("./types/aws-cdk-lib/aws-ses");
      'aws-cdk-lib/aws-ses-actions': typeof import("./types/aws-cdk-lib/aws-ses-actions");
      'aws-cdk-lib/aws-signer': typeof import("./types/aws-cdk-lib/aws-signer");
      'aws-cdk-lib/aws-sns': typeof import("./types/aws-cdk-lib/aws-sns");
      'aws-cdk-lib/aws-sns-subscriptions': typeof import("./types/aws-cdk-lib/aws-sns-subscriptions");
      'aws-cdk-lib/aws-sqs': typeof import("./types/aws-cdk-lib/aws-sqs");
      'aws-cdk-lib/aws-ssm': typeof import("./types/aws-cdk-lib/aws-ssm");
      'aws-cdk-lib/aws-ssmcontacts': typeof import("./types/aws-cdk-lib/aws-ssmcontacts");
      'aws-cdk-lib/aws-ssmincidents': typeof import("./types/aws-cdk-lib/aws-ssmincidents");
      'aws-cdk-lib/aws-sso': typeof import("./types/aws-cdk-lib/aws-sso");
      'aws-cdk-lib/aws-stepfunctions': typeof import("./types/aws-cdk-lib/aws-stepfunctions");
      'aws-cdk-lib/aws-stepfunctions-tasks': typeof import("./types/aws-cdk-lib/aws-stepfunctions-tasks");
      'aws-cdk-lib/aws-synthetics': typeof import("./types/aws-cdk-lib/aws-synthetics");
      'aws-cdk-lib/aws-timestream': typeof import("./types/aws-cdk-lib/aws-timestream");
      'aws-cdk-lib/aws-transfer': typeof import("./types/aws-cdk-lib/aws-transfer");
      'aws-cdk-lib/aws-voiceid': typeof import("./types/aws-cdk-lib/aws-voiceid");
      'aws-cdk-lib/aws-waf': typeof import("./types/aws-cdk-lib/aws-waf");
      'aws-cdk-lib/aws-wafregional': typeof import("./types/aws-cdk-lib/aws-wafregional");
      'aws-cdk-lib/aws-wafv2': typeof import("./types/aws-cdk-lib/aws-wafv2");
      'aws-cdk-lib/aws-wisdom': typeof import("./types/aws-cdk-lib/aws-wisdom");
      'aws-cdk-lib/aws-workspaces': typeof import("./types/aws-cdk-lib/aws-workspaces");
      'aws-cdk-lib/aws-xray': typeof import("./types/aws-cdk-lib/aws-xray");
      'aws-cdk-lib/cloud-assembly-schema': typeof import("./types/aws-cdk-lib/cloud-assembly-schema");
      'aws-cdk-lib/cloudformation-include': typeof import("./types/aws-cdk-lib/cloudformation-include");
      'aws-cdk-lib/core/lib/helpers-internal': typeof import("./types/aws-cdk-lib/core/lib/helpers-internal");
      'aws-cdk-lib/cx-api': typeof import("./types/aws-cdk-lib/cx-api");
      'aws-cdk-lib/lambda-layer-awscli': typeof import("./types/aws-cdk-lib/lambda-layer-awscli");
      'aws-cdk-lib/lambda-layer-kubectl': typeof import("./types/aws-cdk-lib/lambda-layer-kubectl");
      'aws-cdk-lib/lambda-layer-node-proxy-agent': typeof import("./types/aws-cdk-lib/lambda-layer-node-proxy-agent");
      'aws-cdk-lib/pipelines': typeof import("./types/aws-cdk-lib/pipelines");
      'aws-cdk-lib/pipelines/lib/helpers-internal': typeof import("./types/aws-cdk-lib/pipelines/lib/helpers-internal");
      'aws-cdk-lib/region-info': typeof import("./types/aws-cdk-lib/region-info");
      'aws-cdk-lib/triggers': typeof import("./types/aws-cdk-lib/triggers");
  };
  export = _exports;
}
declare module 'cdk-web' {
  import main = require('cdk-web/entrypoint.generated');
  export = main; global { interface Window { CDK: typeof main; }}
}